f = open('1.txt')  # 八进制文件保存在这里  这是目录
temp = []
while True:
    k = f.read(3)  # 三位一组
    if k:
        temp.append(k)
    else:
        break

f.close()
for i in temp:
    num = '0o' + i
    num = int(num, base=0)
    num = chr(num)
    print(num, end='')  # 使用python3版本运行该脚本



import base64

miwen = '4nXna/V7t2LpdLI44mn0fQ=='
mingwen = base64.b64decode(miwen)
print(mingwen)

for i in mingwen:
    # print(type(i))
    print(i, end=" ")

print()
j = 1
for i in mingwen:
    # print(type(i))

    if(j % 2 == 1):
        print(chr(i-128), end="")
    else:
        print(chr(i), end="")
    j += 1
